-- globals
local tostring_ = tostring
local getn = table.getn
local math_floor = math.floor
local math_abs = math.abs
local math_sin								= math.sin
local math_cos								= math.cos
local math_rad								= math.rad
local GetPlayerFacing_						= GetPlayerFacing
local GetPlayerMapPosition_ = GetPlayerMapPosition

-- Isolate the environment
local folder, core = ...
setfenv(1, core)
-- local

--~ local whiteText			= "|cffffffff%s|r"
local strDebugFrom		= "|cffffff00[%s]|r" --Yellow function name. help pinpoint where the debug msg is from.
local strWhiteBar		= "|cffffff00 || |r" -- a white bar to seperate the debug info.
-----------------------------
function Debug(from, ...)	--
-- simple print function.	--
------------------------------
	if version ~= "" then--version's from curse, user doesn't need to see debug msgs.
		return
	end
	local tbl  = {...}
	local msg = tostring_(tbl[1])
	for i=2,getn(tbl) do 
		msg = msg..strWhiteBar..tostring_(tbl[i])
	end
	echo(strDebugFrom:format(from).." "..msg)
end

local colouredName		= "|cff7f7f7f{|r|cffff0000TR|r|cff7f7f7f}|r "
function echo(...)
	local tbl  = {...}
	local msg = tostring_(tbl[1])
	for i=2,getn(tbl) do 
		msg = msg..strWhiteBar..tostring_(tbl[i])
	end
	
	local cf = _G["ChatFrame1"]
	if cf then
		cf:AddMessage(colouredName..msg,.7,.7,.7)
	end
end

------------------------------------------------------------------
function Round(num, zeros)										--
-- zeroes is the number of decimal places. eg 1=*.*, 3=*.***	--
------------------------------------------------------------------
	return math_floor( num * 10 ^ (zeros or 0) + 0.5 ) / 10 ^ (zeros or 0)
end

--[[
function GetZoneSize()--	/run TR.GetZoneData()
	local cC, cZ = Astrolabe:GetCurrentPlayerPosition()
	local _, width, height = Astrolabe:ComputeDistance(  cC, cZ, 0, 0, cC, cZ, 1, 1 )
	return width, height
end
]]


--[[
----------------------------------------------------------------------------------
function GetMyYardCoords()														--
-- Returns our coords in yards instead of map coords.							--
-- Every map has coords of 0-100, but each zone is a different size in yards.	--
----------------------------------------------------------------------------------
	local cC, cZ, cX, cY = Astrolabe:GetCurrentPlayerPosition()
	local dist, x ,y = Astrolabe:ComputeDistance(  cC, cZ, 0, 0, cC, cZ, cX, cY )
	return x, y
end
]]


----------------------------------------------------------------------------------
function GetMyYardCoords2()														--
-- Returns our coords in yards instead of map coords.							--
-- Every map has coords of 0-100, but each zone is a different size in yards.	--
----------------------------------------------------------------------------------
	local mX, mY = GetPlayerMapPosition_("player")
	return CoordsToYardCoords(mX, mY)
end

function CoordsToYardCoords(x, y)
	local found, width, height = core:GetZoneSize()
	local yX = width * x
	local yY = height * y
	return yX, yY
end

function YardCoordsToMapCoords(sX, sY)
	local found, width, height = core:GetZoneSize()
	local tX = sX / width
	local tY = sY / height
	return tX, tY
end

--[[math.deg(GetPlayerFacing())
	North = 0/360
	West = 90
	South = 180
	East = 270]]
----------------------------------
function MyHeading()			--
-- Returns heading in degrees.	--
----------------------------------
	return math.deg(GetPlayerFacing_())
end
----------------------------------------------------------------------------------
function GetTotemCoords(direction)												--
-- Input a direct and this returns the coords 3 yards away in that direction.	--
----------------------------------------------------------------------------------
--~ 	Debug("GetTotemCoords 2", GetMyYardCoords2())
	
	local x, y = GetMyYardCoords2() --Get our coords in yards.

	local heading = MyHeading() + direction --Adjust the heading to compensate for our current direction.
	if (heading < 0) then --Make sure the heading is 0-360. This may not be needed but helped in testing.
		heading = heading + 360;
	elseif heading > 360 then
		heading = heading - 360;
	end
	local tX, tY = GetDirectionCoords(x, y, heading, spawnDistance)

	local cX, cY = YardCoordsToMapCoords(tX, tY)

	local dX, dY = tX - x, tY - y
	return cX, cY
end

----------------------------------------------------------------------------------
function SwitchEW(angle)														--
-- This function switchs east and west directions.								--
----------------------------------------------------------------------------------
	local z = 0 - angle;
	local t = 0 - math_abs(z);
	if t < 0 then
		t = t + 360;
	end
	return t
end


--------------------------------------------------------------------------------------
function GetDirectionCoords(mX, mY, direction, distance)							--
-- Returns a set of coords in a direction and distance of another set of coords.	--
-- Many thanks to Granola of Baelgun server for helping me.							--
--------------------------------------------------------------------------------------
	local direction = direction + 90 -- cos & sin see 360/0deg as east, but GetPlayerFacing sees it at north. We need to adjust for this.
	local direction = SwitchEW(direction) --This seems to work, I don't know why.
	local rad = math_rad(direction)
	local tX = mX + distance * math_cos(rad)
	local tY = mY + distance * math_sin(rad)
	return tX, tY
end

--[[
function YardCoordsToMapCoords(sX, sY)
	local width, height = GetZoneSize()
	local tX = sX / width
	local tY = sY / height
	return tX, tY
end
]]


--~ --------------------------------------------------------------
--~ function AngleToCoords(tX, tY, sX, sY)								--
--~ -- Returns the angle to a set of coords in degrees (0-360).	--
--~ --------------------------------------------------------------
--~ 	if not sX then
--~ 		sX,sY	= GetPlayerMapPosition_("player");
--~ 	end
--~ 	local dX 		= tX - sX;
--~ 	local dY		= sY - tY;
--~ 	local heading = math_deg(math_atan2(dX , dY));
--~ 	
--~ 	
--~ 	if (heading < 0) then
--~ 		heading = heading + 360;
--~ 	elseif heading > 360 then
--~ 		heading = heading - 360;
--~ 	end
--~ 	
--~ 	heading = Round(heading,2);
--~ 	return heading;
--~ end