--Globals
local pairs_ = pairs

-- Isolate the environment
local folder, core = ...
setfenv(1, core)
-- local

CoreOptionsTable = {
	name = titleFull,
	type = "group",
	childGroups = "tab",

	args = {
		core={
			name = L["Core"],
			type = "group",
			order = 1,
			args={}
		},
	},
}



CoreOptionsTable.args.core.args.enable = {
	type = "toggle",	order	= 1,
	name	= L["Enable"],
	desc	= L["Enables / Disables the addon"],
	set = function(info,val) 
		if val == true then
			core:Enable()
		else
			core:Disable()
		end
	end,
	get = function(info) return core:IsEnabled() end
}

defaultSettings.profile.trackOthersTotems = true
CoreOptionsTable.args.core.args.trackOthersTotems = {
	type = "toggle",	order	= 2,
	name	= L["Track other's totems"],
	desc	= L["Add other shaman's totems to your minimap."],
	set = function(info,val) 
		P.trackOthersTotems = val
	end,
	get = function(info) return P.trackOthersTotems end
}

defaultSettings.profile.broadcastTotemLocation = true
CoreOptionsTable.args.core.args.broadcastTotemLocation = {
	type = "toggle",	order	= 3,
	name	= L["Broadcast totem location"],
	desc	= L["Broadcast your totem's location to group members."],
	set = function(info,val) 
		P.broadcastTotemLocation = val
	end,
	get = function(info) return P.broadcastTotemLocation end
}

defaultSettings.profile.totemColour[1]	= {r=1, g=0, b=0, a=0.2} --red
CoreOptionsTable.args.core.args.fireColour = {
	name = L["Fire Colour"],	order	= 10,
	desc = L["Colour of the circle around the totem"],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[1].r = r
		P.totemColour[1].g = g
		P.totemColour[1].b = b
		P.totemColour[1].a = a
		
		for GUID, data in pairs_(activeTotems) do 
			if data.totemSlot == 1 then
				data.icon.solidTexture:SetVertexColor(r, g, b, a);
			end
		end
--~ 		print(Round(r,2), Round(g,2), Round(b,2), Round(a,2))
	end,
	get = function(info) return P.totemColour[1].r, P.totemColour[1].g, P.totemColour[1].b, P.totemColour[1].a end
}

defaultSettings.profile.totemColour[2]	= {r=0, g=1, b=0, a=0.2} --green
CoreOptionsTable.args.core.args.earthColour = {
	name = L["Earth Colour"],	order	= 11,
	desc = L["Colour of the circle around the totem"],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[2].r = r
		P.totemColour[2].g = g
		P.totemColour[2].b = b
		P.totemColour[2].a = a
		
		for GUID, data in pairs_(activeTotems) do 
			if data.totemSlot == 2 then
				data.icon.solidTexture:SetVertexColor(r, g, b, a);
			end
		end
	end,
	get = function(info) return P.totemColour[2].r, P.totemColour[2].g, P.totemColour[2].b, P.totemColour[2].a end
}

defaultSettings.profile.totemColour[3]	= {r=0, g=0, b=1, a=0.2} --blue
CoreOptionsTable.args.core.args.waterColour = {
	name = L["Water Colour"],	order	= 12,
	desc = L["Colour of the circle around the totem"],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[3].r = r
		P.totemColour[3].g = g
		P.totemColour[3].b = b
		P.totemColour[3].a = a
		
		for GUID, data in pairs_(activeTotems) do 
			if data.totemSlot == 3 then
				data.icon.solidTexture:SetVertexColor(r, g, b, a);
			end
		end
	end,
	get = function(info) return P.totemColour[3].r, P.totemColour[3].g, P.totemColour[3].b, P.totemColour[3].a end
}

defaultSettings.profile.totemColour[4]	= {r=1, g=1, b=1, a=0.2} --white
CoreOptionsTable.args.core.args.airColour = {
	name = L["Air Colour"],	order	= 13,
	desc = L["Colour of the circle around the totem"],
	type = "color",
	hasAlpha	= true,
	set = function(info,r,g,b,a) 
		P.totemColour[4].r = r
		P.totemColour[4].g = g
		P.totemColour[4].b = b
		P.totemColour[4].a = a
		
		for GUID, data in pairs_(activeTotems) do 
			if data.totemSlot == 4 then
				data.icon.solidTexture:SetVertexColor(r, g, b, a);
			end
		end
	end,
	get = function(info) return P.totemColour[4].r, P.totemColour[4].g, P.totemColour[4].b, P.totemColour[4].a end
}

defaultSettings.profile.minimapIconRange = 200
CoreOptionsTable.args.core.args.minimapIconRange = {
	type	= "range",	order	= 16,
	name = L["Minimap Show Range"],
	desc = L["Hide the icon if we're beyond * yards away."],
	min		= 50,
	max		= 200,
	step	= 5,
	set = function(info,val) 
		P.minimapIconRange = val;
	end,
	get = function(info) return P.minimapIconRange end
}

defaultSettings.profile.iconSize = 12
CoreOptionsTable.args.core.args.iconSize = {
	type	= "range",	order	= 17,
	name = L["Icon Size"],
	desc = L["Size of the totem icon on the minimap. (Not the circle)"],
	min		= 4,
	max		= 32,
	step	= 4,
	set = function(info,val) 
		P.iconSize = val;
		
		for GUID, data in pairs_(activeTotems) do 
			data.icon:SetWidth(val)
			data.icon:SetHeight(val)
		end
	end,
	get = function(info) return P.iconSize end
}